@@ -14,6 +14,8 @@ class SaveAppUtility:
         self.AppTemplateName = ''
         self.new_app_name = ''
 
+        self.api_missing = False
+
         for vm in self.sandbox.automation_api.GetReservationDetails(self.sandbox.id).ReservationDescription.Resources:
             if vm.Name == self.resource_name:
                 self.app_name = vm.AppDetails.AppName
@@ -22,8 +24,9 @@ class SaveAppUtility:
                     if new_app_name == '':
                         if save_as:
                             if self.app_name == self.AppTemplateName:
-                                raise Exception("Stopping Save As because App's name was not changed prior to deployment.\n"
-                                                "Use the 'NewAppName' custom attribute on the command to override.")
+                                self.api_missing = True
+                                self.sandbox.automation_api.WriteMessageToReservationOutput(self.sandbox.id, "Stopping Save As because App's name was not changed prior to deployment.\n"
+                                                                                                             "Use the 'NewAppName' custom attribute on the command to override.")
                             else:
                                 self.new_app_name = self.app_name
                         else:
@@ -99,7 +102,11 @@ class SaveAppUtility:
             for deploy_path in self.deploy_info['deploypaths']:
                 if deploy_path['is_default']:
                     for key, value in self.saved_app_info.iteritems():
-                        deploy_path['attributes'][key] = value
+                        # patch for AWS
+                        if 'AWS' in key:
+                            deploy_path['attributes']['AWS AMI Id'] = value
+                        else:
+                            deploy_path['attributes'][key] = value
 
         self.app_xml = app_template(self.new_app_name, self.deploy_info['deploypaths'], app_categories, app_attributes,
                                     resource.ResourceModelName, resource.DriverName,
@@ -115,12 +122,14 @@ class SaveAppUtility:
             raise Exception("Error uploading App to CloudShell\n{}".format(result))
 
     def save_flow(self):
-        self.verify_deploy_info_and_display_image()
-        self.save_app_info()
-        self.create_app_xml()
-        self.upload_app()
+        if not self.api_missing:
+            self.verify_deploy_info_and_display_image()
+            self.save_app_info()
+            self.create_app_xml()
+            self.upload_app()
 
     def save_flow_just_app(self):
-        self.verify_deploy_info_and_display_image()
-        self.create_app_xml()
-        self.upload_app()
+        if not self.api_missing:
+            self.verify_deploy_info_and_display_image()
+            self.create_app_xml()
+            self.upload_app()
